@@ -16,7 +16,7 @@ from .config import Config
 # 配置地址--------------------------------------------------------------------------------
 global_config = nonebot.get_driver().config
 pvz_config = Config.parse_obj(global_config.dict())
-pvz_basic_path = pvz_config.pvz_basic_path
+pvz_basic_path = pvz_config.pvz_basic_path / os.getcwd()
 
 bag_path = pvz_basic_path / "user_data" / "bag.txt"
 lawn_path = pvz_basic_path / "user_data" / "lawn.txt"
